@@ -396,11 +396,13 @@ while(<$fh>){
       outword $smichut_orig."", ",,/";
       }
     }
-    if($plural_iim){
-      # I currently decided that in Hebrew, unlike Arabic, only specific
-      # nouns can get the iim (zugi) pluralization, and most nouns can't,
-      # e.g.,  isn't correct (for "two cats") despite a story called
-      #  . This is why this is an option, and not the default.
+    if($plural_iim || $opts{""}){
+      # The difference between  and  is that  adds only the ""
+      # plural, while  adds the plural and its inflections. For example,
+      # for , , , , , one would never say
+      #  (my two years); On the other hand for other words  and all
+      # the inflections it implies makes sense, e.g., consider ,
+      # , .
       my $xword=$word;
       if(substr($xword,-1,1) eq ""){
 	# Change final he into tav before adding the "iim" pluralization.
@@ -410,10 +412,10 @@ while(<$fh>){
       outword $xword."y", ",";
       $smichut=$xword;
       my $smichut_orig=$xword_orig;
-      unless ($opts{"__"}){
+      unless ($opts{"__"} || !$plural_iim){
       outword $smichut_orig."-", ",,"; # smichut
       }
-      unless ($opts{"__"}||$opts{"__"}){
+      unless ($opts{"__"}||$opts{"__"} || !$plural_iim){
       outword $smichut."y",        ",,/"; # possessives (kinu'im)
       outword $smichut."",      ",,/";
       outword $smichut."",       ",,/";
